@@ -1,4 +1,3 @@
-
 /*
 ** grp.h           Group "map" handling functions and structures
 **
@@ -48,23 +47,29 @@ extern struct group *_getgrent(void);
 extern struct group *_getgrnam(const char *name);
 extern struct group *_getgrgid(gid_t gid);
 
-extern void yp_setgrent(void);
-extern void yp_endgrent(void);
-extern struct group *yp_getgrent(void);
-extern struct group *yp_getgrnam(const char *name);
-extern struct group *yp_getgrgid(gid_t gid);
+extern void _yp_setgrent(void);
+extern void _yp_endgrent(void);
+extern struct group *_yp_getgrent(void);
+extern struct group *_yp_getgrnam(const char *name);
+extern struct group *_yp_getgrgid(gid_t gid);
 
-extern void nis_setgrent(void);
-extern void nis_endgrent(void);
-extern struct group *nis_getgrent(void);
-extern struct group *nis_getgrnam(const char *name);
-extern struct group *nis_getgrgid(gid_t gid);
+extern void _nis_setgrent(void);
+extern void _nis_endgrent(void);
+extern struct group *_nis_getgrent(void);
+extern struct group *_nis_getgrnam(const char *name);
+extern struct group *_nis_getgrgid(gid_t gid);
 
-extern void dns_setgrent(void);
-extern void dns_endgrent(void);
-extern struct group *dns_getgrent(void);
-extern struct group *dns_getgrnam(const char *name);
-extern struct group *dns_getgrgid(gid_t gid);
+extern void _dns_setgrent(void);
+extern void _dns_endgrent(void);
+extern struct group *_dns_getgrent(void);
+extern struct group *_dns_getgrnam(const char *name);
+extern struct group *_dns_getgrgid(gid_t gid);
+
+extern void _dbm_setgrent(void);
+extern void _dbm_endgrent(void);
+extern struct group *_dbm_getgrent(void);
+extern struct group *_dbm_getgrnam(const char *name);
+extern struct group *_dbm_getgrgid(gid_t gid);
 
 extern void setgrent(void);
 extern void endgrent(void);
