@@ -33,31 +33,31 @@
 #include <grp.h>
 
 
-void dns_setgrent(void)
+void _dns_setgrent(void)
 {
 }
 
 
-void dns_endgrent(void)
+void _dns_endgrent(void)
 {
 }
 
 
-struct group *dns_getgrent(void)
+struct group *_dns_getgrent(void)
 {
     errno = ECONNREFUSED;
     return NULL;
 }
 
 
-struct group *dns_getgrgid(gid_t gid)
+struct group *_dns_getgrgid(gid_t gid)
 {
     errno = ECONNREFUSED;
     return NULL;
 }
 
 
-struct group *dns_getgrnam(const char *name)
+struct group *_dns_getgrnam(const char *name)
 {
     errno = ECONNREFUSED;
     return NULL;
