@@ -33,24 +33,24 @@
 #include <gshadow.h>
 
 
-void dns_setsgent(void)
+void _dns_setsgent(void)
 {
 }
 
 
-void dns_endsgent(void)
+void _dns_endsgent(void)
 {
 }
 
 
-struct sgrp *dns_getsgent(void)
+struct sgrp *_dns_getsgent(void)
 {
     errno = ECONNREFUSED;
     return NULL;
 }
 
 
-struct sgrp *dns_getsgnam(const char *name)
+struct sgrp *_dns_getsgnam(const char *name)
 {
     errno = ECONNREFUSED;
     return NULL;
