@@ -30,31 +30,31 @@
 #include <netdb/protocols.h>
 
 
-void nis_setprotoent(int stayopen)
+void _nis_setprotoent(int stayopen)
 {
 }
 
 
-void nis_endprotoent(void)
+void _nis_endprotoent(void)
 {
 }
 
 
-struct protoent *nis_getprotoent(void)
+struct protoent *_nis_getprotoent(void)
 {
     errno = ECONNREFUSED;
     return NULL;
 }
 
 
-struct protoent *nis_getprotobyname(const char *name)
+struct protoent *_nis_getprotobyname(const char *name)
 {
     errno = ECONNREFUSED;
     return NULL;
 }
 
 
-struct protoent *nis_getprotobynumber(int number)
+struct protoent *_nis_getprotobynumber(int number)
 {
     errno = ECONNREFUSED;
     return NULL;
