@@ -30,31 +30,31 @@
 #include <netdb/rpc.h>
 
 
-void nis_setrpcent(int stayopen)
+void _nis_setrpcent(int stayopen)
 {
 }
 
 
-void nis_endrpcent(void)
+void _nis_endrpcent(void)
 {
 }
 
 
-struct rpcent *nis_getrpcent(void)
+struct rpcent *_nis_getrpcent(void)
 {
     errno = ECONNREFUSED;
     return NULL;
 }
 
 
-struct rpcent *nis_getrpcbyname(const char *name)
+struct rpcent *_nis_getrpcbyname(const char *name)
 {
     errno = ECONNREFUSED;
     return NULL;
 }
 
 
-struct rpcent *nis_getrpcbynumber(int number)
+struct rpcent *_nis_getrpcbynumber(int number)
 {
     errno = ECONNREFUSED;
     return NULL;
