@@ -108,7 +108,7 @@ static struct group *grent_parse(char *str, int len)
 }
 
 
-void yp_setgrent(void)
+void _yp_setgrent(void)
 {
     rewind_flag = 1;
     if (savekey)
@@ -116,7 +116,7 @@ void yp_setgrent(void)
 }
 
 
-void yp_endgrent(void)
+void _yp_endgrent(void)
 {
     rewind_flag = 1;
     if (savekey)
@@ -124,7 +124,7 @@ void yp_endgrent(void)
 }
 
 
-struct group *yp_getgrent(void)
+struct group *_yp_getgrent(void)
 {
     struct group *gr;
     char *map;
@@ -175,7 +175,7 @@ struct group *yp_getgrent(void)
 }
 
 
-struct group *yp_getgrgid(gid_t gid)
+struct group *_yp_getgrgid(gid_t gid)
 {
     struct group *gr;
     char *map;
@@ -206,7 +206,7 @@ struct group *yp_getgrgid(gid_t gid)
 }
 
 
-struct group *yp_getgrnam(const char *name)
+struct group *_yp_getgrnam(const char *name)
 {
     struct group *gr;
     char *map;
