@@ -91,7 +91,7 @@ static struct protoent *protoent_parse(char *str, int len)
 
 
 
-void yp_setprotoent(int stayopen)
+void _yp_setprotoent(int stayopen)
 {
     rewind_flag = 1;
     if (savekey)
@@ -99,7 +99,7 @@ void yp_setprotoent(int stayopen)
 }
 
 
-void yp_endprotoent(void)
+void _yp_endprotoent(void)
 {
     rewind_flag = 1;
     if (savekey)
@@ -107,7 +107,7 @@ void yp_endprotoent(void)
 }
 
 
-struct protoent *yp_getprotoent(void)
+struct protoent *_yp_getprotoent(void)
 {
     struct protoent *poe;
     char *map;
@@ -180,7 +180,7 @@ struct protoent *yp_getprotoent(void)
 }
 
 
-struct protoent *yp_getprotobyname(const char *name)
+struct protoent *_yp_getprotobyname(const char *name)
 {
     struct protoent *pep;
     char *map;
@@ -208,7 +208,7 @@ struct protoent *yp_getprotobyname(const char *name)
 }
 
 
-struct protoent *yp_getprotobynumber(int number)
+struct protoent *_yp_getprotobynumber(int number)
 {
     char buf[32];
     struct protoent *pep;
@@ -239,3 +239,6 @@ struct protoent *yp_getprotobynumber(int number)
 }
 
 #endif /* ENABLE_YP */
+
+
+
