@@ -35,7 +35,7 @@ int main(int argc, char *argv[])
     struct passwd *pw;
 
 
-    pw = nis_getpwuid(atoi(argv[1]));
+    pw = _nis_getpwuid(atoi(argv[1]));
 
     if (pw)
 	print_passwd(pw);
