@@ -163,8 +163,10 @@ int main(int argc, char *argv[])
 	else
 	    printf("%.*s\n", len, result);
 	
-    } while ((code = yp_next(domain, mapname, outkey, keylen, &outkey, &keylen,
-			    &result, &len)) == 0);
+    } while ((code = yp_next(domain, mapname,
+			     outkey, keylen,
+			     &outkey, &keylen,
+			     &result, &len)) == 0);
 
     if (code != YPERR_NOMORE)
     {
